'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.lookup = exports.isPathExists = undefined;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var debug = (0, _debug2.default)('eslint:plugin:import-resolver-babel-namespace:map-babel-namespace');

/**
 * Cache storage
 *
 * @type {Object}
 */
/**
 * UTILITIES
 * =========
 */
var cache = {
    readFile: {},
    isPathExists: {}
};

/**
 * Check if file exists.
 *
 * @param {String} filename
 *
 * @return {Boolean}
 */
var isPathExists = function isPathExists(filename) {
    if (!filename) {
        return false;
    }

    if (!cache.isPathExists[filename]) {
        cache.isPathExists[filename] = _fs2.default.existsSync(filename);
    }

    return cache.isPathExists[filename];
};

/**
 * Read the given filename.
 *
 * @param {String} filename
 *
 * @return {Object}
 */
var readFile = function readFile(filename) {
    if (!filename) {
        throw new Error('filename must be a string');
    }

    if (!cache.readFile[filename]) {
        cache.readFile[filename] = _fs2.default.readFileSync(filename, 'utf8');
    }

    return cache.readFile[filename];
};

/**
 * The purpose of this module, is to find the project's file and cache whenever an option changes.
 * The lookup logic is starting from the directory of the reference file.
 *
 * @param {String} directory
 * @param {String} filename
 *
 * @return {Object}
 */
var lookup = function lookup(directory, filename) {
    if (!directory) {
        return null;
    }

    var lookupPath = _path2.default.join(directory, filename);

    debug('Lookup: %s', lookupPath);

    if (isPathExists(lookupPath)) {
        return {
            content: readFile(lookupPath),
            lookupPath: lookupPath
        };
    }

    var parentDirectory = _path2.default.dirname(directory);

    // We are in root stop the loop or maybe we are has been in the root of the project directory
    if (parentDirectory === directory) {
        debug('Lookup: has been reached the root directory. Cannot resolve file: ', filename);

        return null;
    }

    return lookup(parentDirectory, filename);
};

exports.isPathExists = isPathExists;
exports.lookup = lookup;